==> v4_navigation_engine-0.1.61.tar.gz: ios/Classes/NavigationV4 (1)/Navigation/View/PauseRunViewController.swift <==
//
//  PauseRunViewController.swift
//  NavigationUI
//
//  Created by hassine othmane on 4/24/20.
//  Copyright © 2020 com.mile. All rights reserved.
//

import UIKit
import MessageUI


protocol MyPauseRunDelegate{

    func playMyNavigation()
    func stopMyNavigation()
    func manageVoice()
}



public class PauseRunViewController: UIViewController, MFMessageComposeViewControllerDelegate {
    public func messageComposeViewController(_ controller: MFMessageComposeViewController, didFinishWith result: MessageComposeResult) {
         self.dismiss(animated: true, completion: nil)
    }


    var delegate: MyPauseRunDelegate?
    @IBOutlet weak var continue_btn: UIButton!
    @IBOutlet weak var popup_view: UIView!

    @IBOutlet weak var finish_btn: UIButton!
    @IBOutlet weak var container_view: UIView!

    @IBOutlet weak var time_imageView: UIImageView!
    @IBOutlet weak var kmTitle_lbl: UILabel!
    @IBOutlet weak var km_lbl: UILabel!

    @IBOutlet weak var duration_lbl: UILabel!

    @IBOutlet weak var durationTitle_lbl: UILabel!

    @IBOutlet weak var timer_lbl: UILabel!

    @IBOutlet weak var km_imageView: UIImageView!


    @IBOutlet weak var sms_btn: UIButton!
    @IBOutlet weak var audio_switch: UISwitch!
    
    @IBOutlet weak var audioGuide_btn: UIButton!
    
  
    var historic : Historic?
    var user : MyUser?
    var isMuted : Bool = false

    var whiteLabel : WhiteLabel?
    var flutterGPSColor : String?

    public override func viewDidLoad() {
        super.viewDidLoad()
    finish_btn.primaryStyle(color: UIColor(red: 0.95, green: 0.35, blue: 0.32, alpha: 1.00))
    continue_btn.primaryStyle()
        // Do any additional setup after loading the view.
        if(whiteLabel!.isWhiteLabel!) {
            self.continue_btn.backgroundColor = UIColor(hex: self.flutterGPSColor!+"FF")
            self.continue_btn.titleLabel!.font = Style.shared.btnPrimaryFont
            self.continue_btn.setTitleColor(UIColor.white, for: .normal)
            self.continue_btn.layer.cornerRadius = Style.shared.btnCornerRaduis
            self.continue_btn.setTitle("CONTINUE_VISIT".localized.uppercased(), for: .normal)
        } else {
            continue_btn.primaryStyle()
        }
         popup_view.layer.cornerRadius = 30
            popup_view.layer.masksToBounds = true
            

            let blurEffect = UIBlurEffect(style: UIBlurEffect.Style.dark)
            let blurEffectView = UIVisualEffectView(effect: blurEffect)
            blurEffectView.frame = container_view.bounds
            blurEffectView.autoresizingMask = [.flexibleWidth, .flexibleHeight]
            blurEffectView.alpha = 0.75
            container_view.insertSubview(blurEffectView, belowSubview: popup_view)


        duration_lbl.headerStyle(color: UIColor.white)
        km_lbl.headerStyle(color: UIColor.white)

        kmTitle_lbl.title1Style(color:  UIColor.white)
        durationTitle_lbl.title1Style(color:  UIColor.white)
        sms_btn.setTitle("EmergencySMS".localized, for: UIControl.State.normal)
        audioGuide_btn.setTitle("Audio Guide", for: UIControl.State.normal)
        sms_btn.clearStyle2(textColor: Style.shared.accentColor)
        audioGuide_btn.clearStyle2(textColor: Style.shared.accentColor)
        continue_btn.setTitle("CONTINUERUNNING".localized, for: UIControl.State.normal)
        pause_lbl.text = "RunPaused".localized
        
        
        
        let index = UserDefaults.standard.integer(forKey: "UnitDistanceV4")
        if index == 0
        {
                km_lbl.text = String(format:"%.1f",Double(historic?.distanceTravelled ?? 0)/1000)
                    kmTitle_lbl.text = " km"

                    duration_lbl.text = String(format:"%.1f",historic?.mediumSpeed ?? 0)
                    durationTitle_lbl.text = " km/h"
        }
        else if index == 1
        {
           
            
            km_lbl.text = String(format:"%.1f",Double(historic?.distanceTravelled ?? 0)/1609)
                  kmTitle_lbl.text = " mile"

                  duration_lbl.text = String(format:"%.1f",historic?.mediumSpeed ?? 0)
                  durationTitle_lbl.text = " mile/h"
        }
        
        
        
      

        timer_lbl.timerCradStyle()
        timer_lbl.text = "\(historic?.time.secondsToHoursMinutesSeconds() ?? 0.secondsToHoursMinutesSeconds())"
        pause_lbl.headerStyle(color: UIColor.white)
            // Do any additional setup after loading the view.




       // pause_lbl.text = "aefds".localized
       // continue_btn.setTitle("".localized, for: UIControl.State.normal)

         if(self.whiteLabel?.isWhiteLabel ?? false) {
            pause_lbl.text = "VISIT_PAUSED".localized
        } else {
            pause_lbl.text = "RUN_PAUSED".localized
        }
        finish_btn.setTitle("finish".localized.uppercased(), for: UIControl.State.normal)

         if(whiteLabel!.isWhiteLabel!) {
           audio_switch.onTintColor = UIColor(hex: self.flutterGPSColor!+"FF")
        }
        if isMuted
        {
            audio_switch.isOn = false
        }
        else
        {
       
            audio_switch.isOn = true
        
        }
        }

    @IBOutlet weak var pause_lbl: UILabel!
    @IBAction func dismiss_action(_ sender: Any) {
            self.dismiss(animated: true) {
                self.delegate?.playMyNavigation()
            }
        }
    
    @IBAction func finish_action(_ sender: Any) {

        self.dismiss(animated: true) {
            self.delegate?.stopMyNavigation()
        }


       

    }


    @IBAction func switchAudio_action(_ sender: Any) {
        self.delegate?.manageVoice()
    }

    @IBAction func sendEmergencySMS(){
        //Permet d'envoyer un SMS d'urgence contenant la position utilisateur dans un lien Maps.
        //Si l'utilisateur a sélectionné un contact d'urgence, on le pré-remplit.

        let alertController = UIAlertController(title: "", message:
            "ASK_SEND_SMS_EMERGENCY".localized, preferredStyle: UIAlertController.Style.alert)
        alertController.addAction(UIAlertAction(title: NSLocalizedString("CANCEL", comment: ""), style: UIAlertAction.Style.default,handler: nil))
        alertController.addAction(UIAlertAction(title: NSLocalizedString("YES", comment: ""), style: UIAlertAction.Style.destructive,handler: {
            (alert: UIAlertAction!) in
            if (MFMessageComposeViewController.canSendText()) {
                //self.delegate?.stopMyNavigation()

                let controller = MFMessageComposeViewController()
//                if let firstname = UserProfile.sharedInstance.firstname, let lastName = UserProfile.sharedInstance.lastname {
//                    controller.body =  String.localizedStringWithFormat(NSLocalizedString("EMERGENCY_TEXT_WITH_NAME", comment: "waiting for a GPS signal"), firstname, lastName, self.myPosition.coordinate.latitude.description, self.myPosition.coordinate.longitude.description)
//                }else{
                
               var myPosition = LocationService.shared.getCurrentLocation()
                
                controller.body =  String.localizedStringWithFormat(NSLocalizedString("EMERGENCY_TEXT", comment: "waiting for a GPS signal"), myPosition!.coordinate.latitude.description, myPosition!.coordinate.longitude.description)
                //}
//                if let number = UserProfile.sharedInstance.emergencyContactPhone {
//                    controller.recipients = [number]
//                }

                controller.messageComposeDelegate = self

                self.present(controller, animated: true,  completion:{
                  //  Analytics.logEvent("sms_emergency_push", parameters: nil)
                })
            }
        }))
        self.present(alertController, animated: true, completion: nil)
    }


    

    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        // Get the new view controller using segue.destination.
        // Pass the selected object to the new view controller.
    }
    */

}

==> v4_navigation_engine-0.1.80.tar.gz: ios/Classes/NavigationV4 (1)/Navigation/View/PauseRunViewController.swift <==
//
//  PauseRunViewController.swift
//  NavigationUI
//
//  Created by hassine othmane on 4/24/20.
//  Copyright © 2020 com.mile. All rights reserved.
//

import UIKit
import MessageUI


protocol MyPauseRunDelegate{

    func playMyNavigation()
    func stopMyNavigation()
    func manageVoice()
}



public class PauseRunViewController: UIViewController, MFMessageComposeViewControllerDelegate {
    public func messageComposeViewController(_ controller: MFMessageComposeViewController, didFinishWith result: MessageComposeResult) {
         self.dismiss(animated: true, completion: nil)
    }


    var delegate: MyPauseRunDelegate?
    @IBOutlet weak var continue_btn: UIButton!
    @IBOutlet weak var popup_view: UIView!

    @IBOutlet weak var finish_btn: UIButton!
    @IBOutlet weak var container_view: UIView!

    @IBOutlet weak var time_imageView: UIImageView!
    @IBOutlet weak var kmTitle_lbl: UILabel!
    @IBOutlet weak var km_lbl: UILabel!

    @IBOutlet weak var duration_lbl: UILabel!

    @IBOutlet weak var durationTitle_lbl: UILabel!

    @IBOutlet weak var timer_lbl: UILabel!

    @IBOutlet weak var km_imageView: UIImageView!


    @IBOutlet weak var sms_btn: UIButton!
    @IBOutlet weak var audio_switch: UISwitch!
    
    @IBOutlet weak var audioGuide_btn: UIButton!
    
  
    var historic : Historic?
    var user : MyUser?
    var isMuted : Bool = false

    var whiteLabel : WhiteLabel?
    var flutterGPSColor : String?

    public override func viewDidLoad() {
        super.viewDidLoad()
    finish_btn.primaryStyle(color: UIColor(red: 0.95, green: 0.35, blue: 0.32, alpha: 1.00))
    continue_btn.primaryStyle()
        // Do any additional setup after loading the view.
        if(whiteLabel!.isWhiteLabel!) {
            self.continue_btn.backgroundColor = UIColor(hex: self.flutterGPSColor!+"FF")
            self.continue_btn.titleLabel!.font = Style.shared.btnPrimaryFont
            self.continue_btn.setTitleColor(UIColor.white, for: .normal)
            self.continue_btn.layer.cornerRadius = Style.shared.btnCornerRaduis
            self.continue_btn.setTitle("CONTINUE_VISIT".localized.uppercased(), for: .normal)
        } else {
            continue_btn.primaryStyle()
        }
         popup_view.layer.cornerRadius = 30
            popup_view.layer.masksToBounds = true
            

            let blurEffect = UIBlurEffect(style: UIBlurEffect.Style.dark)
            let blurEffectView = UIVisualEffectView(effect: blurEffect)
            blurEffectView.frame = container_view.bounds
            blurEffectView.autoresizingMask = [.flexibleWidth, .flexibleHeight]
            blurEffectView.alpha = 0.75
            container_view.insertSubview(blurEffectView, belowSubview: popup_view)


        duration_lbl.headerStyle(color: UIColor.white)
        km_lbl.headerStyle(color: UIColor.white)

        kmTitle_lbl.title1Style(color:  UIColor.white)
        durationTitle_lbl.title1Style(color:  UIColor.white)
        sms_btn.setTitle("EmergencySMS".localized, for: UIControl.State.normal)
        audioGuide_btn.setTitle("Audio Guide", for: UIControl.State.normal)
        sms_btn.clearStyle2(textColor: Style.shared.accentColor)
        audioGuide_btn.clearStyle2(textColor: Style.shared.accentColor)
        continue_btn.setTitle("CONTINUE_RUNNING".localized, for: UIControl.State.normal)
        pause_lbl.text = "RunPaused".localized
        
        
        
        let index = UserDefaults.standard.integer(forKey: "UnitDistanceV4")
        if index == 0
        {
                km_lbl.text = String(format:"%.1f",Double(historic?.distanceTravelled ?? 0)/1000)
                    kmTitle_lbl.text = " km"

                    duration_lbl.text = String(format:"%.1f",historic?.mediumSpeed ?? 0)
                    durationTitle_lbl.text = " km/h"
        }
        else if index == 1
        {
           
            
            km_lbl.text = String(format:"%.1f",Double(historic?.distanceTravelled ?? 0)/1609)
                  kmTitle_lbl.text = " mile"

                  duration_lbl.text = String(format:"%.1f",historic?.mediumSpeed ?? 0)
                  durationTitle_lbl.text = " mile/h"
        }
        
        
        
      

        timer_lbl.timerCradStyle()
        timer_lbl.text = "\(historic?.time.secondsToHoursMinutesSeconds() ?? 0.secondsToHoursMinutesSeconds())"
        pause_lbl.headerStyle(color: UIColor.white)
            // Do any additional setup after loading the view.




       // pause_lbl.text = "aefds".localized
       // continue_btn.setTitle("".localized, for: UIControl.State.normal)

         if(self.whiteLabel?.isWhiteLabel ?? false) {
            pause_lbl.text = "VISIT_PAUSED".localized
        } else {
            pause_lbl.text = "RUN_PAUSED".localized
        }
        finish_btn.setTitle("finish".localized.uppercased(), for: UIControl.State.normal)

         if(whiteLabel!.isWhiteLabel!) {
           audio_switch.onTintColor = UIColor(hex: self.flutterGPSColor!+"FF")
        }
        if isMuted
        {
            audio_switch.isOn = false
        }
        else
        {
       
            audio_switch.isOn = true
        
        }
        }

    @IBOutlet weak var pause_lbl: UILabel!
    @IBAction func dismiss_action(_ sender: Any) {
            self.dismiss(animated: true) {
                self.delegate?.playMyNavigation()
            }
        }
    
    @IBAction func finish_action(_ sender: Any) {

        self.dismiss(animated: true) {
            self.delegate?.stopMyNavigation()
        }


       

    }


    @IBAction func switchAudio_action(_ sender: Any) {
        self.delegate?.manageVoice()
    }

    @IBAction func sendEmergencySMS(){
        //Permet d'envoyer un SMS d'urgence contenant la position utilisateur dans un lien Maps.
        //Si l'utilisateur a sélectionné un contact d'urgence, on le pré-remplit.

        let alertController = UIAlertController(title: "", message:
            "ASK_SEND_SMS_EMERGENCY".localized, preferredStyle: UIAlertController.Style.alert)
        alertController.addAction(UIAlertAction(title: NSLocalizedString("CANCEL", comment: ""), style: UIAlertAction.Style.default,handler: nil))
        alertController.addAction(UIAlertAction(title: NSLocalizedString("YES", comment: ""), style: UIAlertAction.Style.destructive,handler: {
            (alert: UIAlertAction!) in
            if (MFMessageComposeViewController.canSendText()) {
                //self.delegate?.stopMyNavigation()

                let controller = MFMessageComposeViewController()
//                if let firstname = UserProfile.sharedInstance.firstname, let lastName = UserProfile.sharedInstance.lastname {
//                    controller.body =  String.localizedStringWithFormat(NSLocalizedString("EMERGENCY_TEXT_WITH_NAME", comment: "waiting for a GPS signal"), firstname, lastName, self.myPosition.coordinate.latitude.description, self.myPosition.coordinate.longitude.description)
//                }else{
                
               var myPosition = LocationService.shared.getCurrentLocation()
                
                controller.body =  String.localizedStringWithFormat(NSLocalizedString("EMERGENCY_TEXT", comment: "waiting for a GPS signal"), myPosition!.coordinate.latitude.description, myPosition!.coordinate.longitude.description)
                //}
//                if let number = UserProfile.sharedInstance.emergencyContactPhone {
//                    controller.recipients = [number]
//                }

                controller.messageComposeDelegate = self

                self.present(controller, animated: true,  completion:{
                  //  Analytics.logEvent("sms_emergency_push", parameters: nil)
                })
            }
        }))
        self.present(alertController, animated: true, completion: nil)
    }


    

    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        // Get the new view controller using segue.destination.
        // Pass the selected object to the new view controller.
    }
    */

}
